@@ -1,23 +1,24 @@
 #Load the package's data set
-data(hapmapCEU)
-#Creates a data frame "CEUSNP" of genotype data and a vector "CEUDist" 
+data(CEUData)
+#Creates a data frame "CEUSNP" of genotype data and a vector "CEUDist"
 #of physical locations of the SNPs
 
-	#### Produce a heat map in blue-green-red color scheme ####
-MyHeatmap <- LDheatmap(CEUSNP, genetic.distances = CEUDist, 
-  color = LDheatmap.rainbow(20))
+        #### Produce a heat map in a grey color scheme ####
 
-# Prompt the user before starting a new page of graphics output               
+MyHeatmap <- LDheatmap(CEUSNP, genetic.distances = CEUDist,
+  color = grey.colors(20))
+
+# Prompt the user before starting a new page of graphics output
 # and save the original prompt settings in old.prompt.
 old.prompt <- grid.prompt(TRUE)
 
-# Highlight a certain LD block of interest:                            
+# Highlight a certain LD block of interest:
 LDheatmap.highlight(MyHeatmap, i = 3, j = 8, col = "black", fill = "grey" )
-# Plot a symbol in the center of the pixel which represents LD between  
-# the fourth and seventh SNPs:                                            
+# Plot a symbol in the center of the pixel which represents LD between
+# the fourth and seventh SNPs:
 LDheatmap.marks(MyHeatmap,  4,  7,  gp=gpar(cex=2),  pch = "*")
 
-	#### Modify the plot by using 'grid.edit' function #### 
+        #### Modify the plot by using 'grid.edit' function ####
 #Draw a heat map where the SNPs "rs2283092" and "rs6979287" are labelled.
 LDheatmap(MyHeatmap, SNP.name = c("rs2283092", "rs6979287"))
 
@@ -27,11 +28,11 @@ getNames()
 
 # Find the names of the component grobs of "ldheatmap"
 childNames(grid.get("ldheatmap"))
-#[1] "heatMap" "geneMap" "Key"   
+#[1] "heatMap" "geneMap" "Key"
 
 #Find the names of the component grobs of heatMap
 childNames(grid.get("heatMap"))
-#[1] "heatmap" "title" 
+#[1] "heatmap" "title"
 
 #Find the names of the component grobs of geneMap
 childNames(grid.get("geneMap"))
@@ -39,7 +40,7 @@ childNames(grid.get("geneMap"))
 
 #Find the names of the component grobs of Key
 childNames(grid.get("Key"))
-#[1] "colorKey" "title"    "labels"   "ticks"    "box"    
+#[1] "colorKey" "title"    "labels"   "ticks"    "box"
 
 #Change the plotting symbols that identify SNPs rs2283092 and rs6979287
 #on the plot to bullets
@@ -55,55 +56,53 @@ grid.edit(gPath("ldheatmap", "geneMap","SNPnames"), gp = gpar(cex=1.5))
 grid.edit(gPath("ldheatmap", "heatMap", "heatmap"), gp = gpar(col = "white",
     lwd = 2))
 
+        #### Modify a heat map using 'editGrob' function ####
+MyHeatmap <- LDheatmap(MyHeatmap, color = grey.colors(20))
 
-	#### Modify a heat map using 'editGrob' function ####
-MyHeatmap <- LDheatmap(MyHeatmap, color = LDheatmap.rainbow(20))
-
-new.grob <- editGrob(MyHeatmap$LDheatmapGrob, gPath("geneMap", "segments"), 
-	gp=gpar(col="orange")) 
+new.grob <- editGrob(MyHeatmap$LDheatmapGrob, gPath("geneMap", "segments"),
+        gp=gpar(col="orange"))
 
  ##Clear the old graphics object from the display before drawing the modified heat map:
 grid.newpage()
 
-grid.draw(new.grob) 
-# now the colour of line segments connecting the SNP 
+grid.draw(new.grob)
+# now the colour of line segments connecting the SNP
 # positions to the LD heat map has been changed from black to orange.
 
-
-	#### Draw a resized heat map ####
+        #### Draw a resized heat map (in a 'blue-to-red' color scale ####
 grid.newpage()
 
 pushViewport(viewport(width=0.5, height=0.5))
-LDheatmap(MyHeatmap, SNP.name = c("rs2283092", "rs6979287"), newpage=FALSE)
+LDheatmap(MyHeatmap, SNP.name = c("rs2283092", "rs6979287"), newpage=FALSE,
+color="blueToRed")
 popViewport()
 
-
-	#### Draw and modify two heat maps on one plot #### 
+        #### Draw and modify two heat maps on one plot ####
 grid.newpage()
 
   ##Draw and the first heat map on the left half of the graphics device
-pushViewport(viewport(x=0,width=0.5,just="left"))
-LD1<-LDheatmap(MyHeatmap, color=LDheatmap.rainbow(20), newpage=FALSE, 
-	title="Pairwise LD in LDheatmap.rainbow(20)", 
-	SNP.name="rs6979572", geneMapLabelX=0.6, 
-	geneMapLabelY=0.4, name="ld1")
+pushViewport(viewport(x=0, width=0.5, just="left"))
+LD1<-LDheatmap(MyHeatmap, color=grey.colors(20), newpage=FALSE,
+        title="Pairwise LD in grey.colors(20)",
+        SNP.name="rs6979572", geneMapLabelX=0.6,
+        geneMapLabelY=0.4, name="ld1")
  upViewport()
 
  ##Draw the second heat map on the right half of the graphics device
 pushViewport(viewport(x=1,width=0.5,just="right"))
 LD2<-LDheatmap(MyHeatmap, newpage=FALSE, title="Pairwise LD in heat.colors(20)",
-	SNP.name="rs6979572", geneMapLabelX=0.6, geneMapLabelY=0.4, name="ld2")
+        SNP.name="rs6979572", geneMapLabelX=0.6, geneMapLabelY=0.4, name="ld2")
 upViewport()
 
- ##Modify the text size of main title of the first heat map. 
+ ##Modify the text size of main title of the first heat map.
 grid.edit(gPath("ld1", "heatMap","title"), gp=gpar(cex=1.5))
 
- ##Modify the text size and color of the SNP label of the second heat map. 
+ ##Modify the text size and color of the SNP label of the second heat map.
  grid.edit(gPath("ld2", "geneMap","SNPnames"), gp=gpar(cex=1.5, col="DarkRed"))
 
-	#### Draw a lattice-like plot with heat maps in panels ####
+        #### Draw a lattice-like plot with heat maps in panels ####
 # Load CHBJPTSNP and CHBJPTDist
-data(CHBJPTData) 
+data(CHBJPTData)
 # Make a variable which indicates Chinese vs. Japanese
 pop <- factor(c(rep("chinese",45), rep("japanese",45)))
 library(lattice)
@@ -113,6 +112,6 @@ type="n", scales=list(draw=FALSE), xlab="", ylab="",
 panel=function(x, y, subscripts,...) {
           LDheatmap(CHBJPTSNP[subscripts,], CHBJPTDist, newpage=FALSE) })
 
-#Reset the user's setting for prompting on the graphics output 
+#Reset the user's setting for prompting on the graphics output
 #to the original value before running these example commands.
  grid.prompt(old.prompt)
